summaryrefslogtreecommitdiffstats
path: root/avahi-common/alternative.h
diff options
context:
space:
mode:
authorLennart Poettering <lennart@poettering.net>2005-08-14 02:33:41 +0000
committerLennart Poettering <lennart@poettering.net>2005-08-14 02:33:41 +0000
commitfcc9b0efe1accdb0edcb3143a8e15782e69383db (patch)
tree38589765599804bee4808d49d5695f8a5e7c56c4 /avahi-common/alternative.h
parent7934ca5e102693ba02d9ca6dcdee4960f2ba1a64 (diff)
* doxygen documentation updates
* make AvahiPoll objects const * make poll() functions pluggable in AvahiSimplePoll git-svn-id: file:///home/lennart/svn/public/avahi/trunk@314 941a03a8-eaeb-0310-b9a0-b1bbd8fe43fe
Diffstat (limited to 'avahi-common/alternative.h')
-rw-r--r--avahi-common/alternative.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/avahi-common/alternative.h b/avahi-common/alternative.h
index 3d7b2fe..fa45d96 100644
--- a/avahi-common/alternative.h
+++ b/avahi-common/alternative.h
@@ -22,24 +22,28 @@
USA.
***/
-#include <avahi-common/cdecl.h>
-
/** \file alternative.h Functions to find alternative names for hosts and services in the case of name collision */
+#include <avahi-common/cdecl.h>
+
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
AVAHI_C_DECL_BEGIN
+#endif
/** Find an alternative for the specified host name. If called with an
* original host name, "2" is appended, Afterwards the number is
* increased on each call. (i.e. "foo" becomes "foo2" becomes "foo3"
* and so on.) g_free() the result. */
char *avahi_alternative_host_name(const char *s);
/** Find an alternative for the specified service name. If called with
an original service name, " #2" is appended. Afterwards the number
is increased on each call (i.e. "foo" becomes "foo #2" becomes
- "foo #3" and so on.) g_free() the result. */
+ "foo #3" and so on.) avahi_free() the result. */
char *avahi_alternative_service_name(const char *s);
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
AVAHI_C_DECL_END
+#endif
#endif
@@ -22,24 +22,28 @@
* original host name, "2" is appended, Afterwards the number is
* increased on each call. (i.e. "foo" becomes "foo2" becomes "foo3"
- * and so on.) g_free() the result. */
+ * and so on.) avahi_free() the result. */
char *avahi_alternative_host_name(const char *s);
/** Find an alternative for the specified service name. If called with